import { ChangeDetectorRef, Component, EventEmitter, Input, OnInit, } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { Bu1Model, MyBu1Model } from 'src/app/shared/model/bu1.model';
import { Bu1Service } from 'src/app/shared/services/bu1.service';

@Component({
  selector: 'app-department-register',
  templateUrl: './department-register.component.html',
  styleUrls: ['./department-register.component.scss']
})
export class DepartmentRegisterComponent implements OnInit {
  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  bu1List: Bu1Model[] = []
  bu1ListLoading = false
  bu1: Bu1Model = new MyBu1Model({})
  search = ""
  constructor(private bu1Service: Bu1Service,
    private toastr: ToastrService,
    private cdr: ChangeDetectorRef
  ) { }
  ngOnInit(): void {
    this.getBu1List()
  }
  getBu1List() {
    this.bu1ListLoading = true
    this.bu1Service.getList().subscribe({
      next: response => {
        this.bu1List = response
        this.bu1ListLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.bu1ListLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.bu1ListFilter().length / 10) }, (_, i) => i + 1);
  }
  bu1ListFilter() {
    return this.bu1List.filter(x => x.bu1id.includes(this.search) ||
      x.tdesc.includes(this.search) ||
      x.edesc.includes(this.search))
  }
  selectBu1(bu1?: Bu1Model) {
    this.bu1 = new MyBu1Model(bu1 || {})
  }

  showSuccessAdd() {
    this.toastr.success('บันทึกข้อมูลสำเร็จ', 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  addBu1() {
    this.bu1Service.post(this.bu1).subscribe((response: any) => {
      if (response.success) {
        this.showSuccessAdd()
        this.getBu1List()
      }
    })
  }
  deleteBu1() {
    this.bu1Service.delete(this.bu1).subscribe((response: any) => {
      if (response.success) {
        this.showSuccessDelete()
        this.getBu1List()
      }
    })
  }


}
