import { ChangeDetectorRef, Component, EventEmitter, Input, OnInit, } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { Bu4Model, MyBu4Model } from 'src/app/shared/model/bu4.model';
import { Bu5Model, MyBu5Model } from 'src/app/shared/model/bu5.model';
import { Bu4Service } from 'src/app/shared/services/bu4.service';
import { Bu5Service } from 'src/app/shared/services/bu5.service';
interface table {
  currentPage: number,
  page: number[],
  search: string
}
@Component({
  selector: 'app-sub-department-two',
  templateUrl: './sub-department-two.component.html',
  styleUrls: ['./sub-department-two.component.scss']
})
export class SubDepartmentTwoComponent implements OnInit {
  bu5List: Bu5Model[] = []
  bu5: Bu5Model = new MyBu5Model({})
  bu5Table: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  bu5Modal: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  bu4List: Bu4Model[] = []
  bu4: Bu4Model = new MyBu4Model({})
  bu4Modal: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  currentModal = ""
  constructor(private bu5Service: Bu5Service,
    private bu4Service: Bu4Service,
    private toastr: ToastrService,
    private cdr: ChangeDetectorRef
  ) { }
  ngOnInit(): void {
    this.getBu5List()
    this.getBu4List()
  }
  getBu5List() {
    this.bu5Service.getList().subscribe(response => {
      this.bu5List = response
      this.onBu5TableSearchChange()
      this.cdr.detectChanges()
    })
  }
  onBu5TableSearchChange() {
    this.bu5Table.currentPage = 1
    this.bu5Table.page = Array.from({ length: Math.ceil(this.filterBu5Table().length / 10) }, (_, i) => i + 1);
  }
  filterBu5Table() {
    return this.bu5List.filter(x => x.bu5id.includes(this.bu5Table.search) ||
      x.tdesc.includes(this.bu5Table.search) ||
      x.edesc.includes(this.bu5Table.search))
  }
  selectBu5(bu5?: Bu5Model) {
    this.bu5 = new MyBu5Model(bu5 || {})
    this.selectBu4()
    if (this.bu5.parent) {
      this.bu4Service.getById(this.bu5.parent).subscribe(response => {
        this.bu4 = new MyBu4Model(response)
        this.cdr.detectChanges()
      })
    }
  }
  bu5idChange() {
    const bu5 = this.bu5List.find(x => x.bu5id == this.bu5.bu5id)
    this.selectBu5(bu5 || new MyBu5Model({ bu5id: this.bu5.bu5id }))
  }
  onBu5ModalSearchChange() {
    this.bu5Modal.currentPage = 1
    this.bu5Modal.page = Array.from({ length: Math.ceil(this.filterBu5Modal().length / 10) }, (_, i) => i + 1);
  }
  filterBu5Modal() {
    return this.bu5List.filter(x => x.bu5id.includes(this.bu5Modal.search) ||
      x.tdesc.includes(this.bu5Modal.search) ||
      x.edesc.includes(this.bu5Modal.search))
  }
  addBu5() {
    this.bu5Service.post({ ...this.bu5, parent: this.bu4.bu4id }).subscribe((response: any) => {
      if (response.success) {
        this.getBu5List()
        this.showSuccessAdd()
      }
    })
  }
  deleteBu5() {
    this.bu5Service.delete(this.bu5).subscribe((response: any) => {
      if (response.success) {
        this.getBu5List()
        this.showSuccessDelete()
      }
    })
  }

  getBu4List() {
    this.bu4Service.getList().subscribe(response => {
      this.bu4List = response
      this.onBu4ModalSearchChange()
    })
  }
  onBu4ModalSearchChange() {
    this.bu4Modal.currentPage = 1
    this.bu4Modal.page = Array.from({ length: Math.ceil(this.filterBu4Modal().length / 10) }, (_, i) => i + 1);
  }
  bu4idChange() {
    const bu4 = this.bu4List.find(x => x.bu4id == this.bu4.bu4id)
    this.selectBu4(bu4 || new MyBu4Model({ bu4id: this.bu4.bu4id }))
  }
  filterBu4Modal() {
    return this.bu4List.filter(x => x.bu4id.includes(this.bu4Modal.search) ||
      x.tdesc.includes(this.bu4Modal.search) ||
      x.edesc.includes(this.bu4Modal.search))
  }
  selectBu4(bu4?: Bu4Model) {
    this.bu4 = new MyBu4Model(bu4 || {})
  }

  showSuccessAdd() {
    this.toastr.success('บันทึกข้อมูลสำเร็จ', 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessEdit() {
    this.toastr.success('แก้ไขข้อมูลสำเร็จ', 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
}

