import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { MyCompetencytopicModel } from 'src/app/shared/model/competencytopic.model';
import { MyCompetencytypeModel } from 'src/app/shared/model/competencytype.model';
import { CompetencytopicService } from 'src/app/shared/services/competencytopic.service';
import { CompetencytypeService } from 'src/app/shared/services/competencytype.service';
export interface DataModel {
  id: string
  name: string
  edesc: string
  code: string
  definition: string
  type: DataModel2
  checked: boolean
}
export interface DataModel2 {
  id: string
  name: string
  edesc: string
  code: string
  level: string
}
@Component({
  selector: 'app-competency-topic',
  templateUrl: './competency-topic.component.html',
  styleUrls: ['./competency-topic.component.scss']
})
export class CompetencyTopic {

  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = ""

  currentPageModal = 1
  pageModal = Array.from({ length: 1 }, (_, i) => i + 1);
  searchModal = ""

  @Input() pathTitle = ['การประเมินสมรรถนะ', 'ทะเบียนกำหนดชื่อ', 'หัวข้อสมรรถนะ'];
  @Output() sendPathTitle: EventEmitter<string[]> = new EventEmitter<string[]>();
  activeTab: string = 'tab1'; // กำหนด tab เริ่มต้น

  // ฟังก์ชันในการเปลี่ยนแท็บ
  changeTab(tab: { id: string, text: string }) {
    this.sendPathTitle.emit(['การประเมินสมรรถนะ', 'ตั้งค่าผู้ใช้งาน', tab.text]);
    this.activeTab = tab.id;
  }

  // การจัดการการเปิดปิด modal
  modalOptions: {
    [nameModal: string]: {
      isModalOpen: boolean;
      modalSize: string;
      backdropClose: boolean;
    };
  } = {
      "add": {
        isModalOpen: false,
        modalSize: 'm',
        backdropClose: true,
      },
      "edit": {
        isModalOpen: false,
        modalSize: 'm',
        backdropClose: true,
      }
    };
  // [
  //   ['CC-01', 'จิตสำนึกด้านความปลอดภัยและคุณภาพ (Safety & Quality)','CC'],
  //   ['CC-02', 'การทำงานเป็นทีมแบบ TAT (TAT Teamwork)','CC'],
  //   ['CC-03', 'ความรับผิดชอบในหน้าที่และโปร่งใส (Accountability & Ethics)','CC'],
  //   ['MC-01', 'การคิดเชิงกลยุทธิ์ (Strategic Thinking)','MC'],
  //   ['MC-02', 'การมีทัศนคติเชิงบวก (Mindset-Growth)','MC'],
  //   ['PC-01', 'ความรู้ด้านกฏหมายแรงงาน, กฏหมายแพ่งภาณิชย์, กฏหมายอาญา','PC']

  mockData: DataModel[] = []
  dataLoading = false
  dataSelect: DataModel = { id: "", name: "", edesc: "", code: "", definition: "", type: { id: "", name: "", edesc: "", code: "", level: "" }, checked: false }
  competencytypeListLoading = false
  competencytypeList: DataModel2[] = []
  mockDataSelect: any = []
  openModal(name: string, size: string, closeOnBackdrop?: boolean) {
    this.modalOptions[name].modalSize = size;
    this.modalOptions[name].backdropClose = closeOnBackdrop || false;
    this.modalOptions[name].isModalOpen = true;
    this.currentModal = name;  // ตั้งค่าค่าของ currentModal เป็น 'add' หรือ 'edit'
    document.body.style.overflow = 'hidden';
  }

  closeModal(name: string) {
    this.modalOptions[name].isModalOpen = false;
    if (!this.isAnyModalOpen()) {
      document.body.style.overflow = ''; // คืนค่าการ Scroll เฉพาะเมื่อ Modal ทั้งหมดปิดแล้ว
    }
  }

  isAnyModalOpen(): boolean {
    return Object.values(this.modalOptions).some(modal => modal.isModalOpen); // ตรวจสอบว่า modal อื่นยังเปิดอยู่หรือไม่
  }

  // ฟังก์ชัน toggle checkbox
  isChecked: boolean = false; // ใช้สำหรับตรวจสอบสถานะของ checkbox

  toggleCheckbox() {
    this.isChecked = !this.isChecked; // สลับสถานะ'
    this.mockData.forEach((item) => {
      item.checked = this.isChecked;
    });
    this.checkSelect();
  }

  checkSelect() {
    this.mockDataSelect = this.mockData.filter(item => item.checked);
  }

  // ฟังก์ชันสำหรับการเพิ่ม ลบ หรือแก้ไข ข้อมูล
  addUser() {
    const body = new MyCompetencytopicModel({
      competencyTopicId: this.dataSelect.id, tdesc: this.dataSelect.name, edesc: this.dataSelect.edesc, competencyDetail: this.dataSelect.definition,
      competencyType: new MyCompetencytypeModel({ competencyTypeId: this.dataSelect.type.id, tdesc: this.dataSelect.type.name, edesc: this.dataSelect.type.edesc, shortName: this.dataSelect.type.code, expectationLevel: this.dataSelect.type.level }),
    })
    this.competencytopicService.post(body).subscribe((response: any) => {
      if (response.success) {
        this.showSuccess()
        this.getCompetencytopicList()
      }
    })
  }
  deleteUser() {
    const body = new MyCompetencytopicModel({
      competencyTopicId: this.dataSelect.id, tdesc: this.dataSelect.name, edesc: this.dataSelect.edesc, competencyDetail: this.dataSelect.definition,
      competencyType: new MyCompetencytypeModel({ competencyTypeId: this.dataSelect.type.id, tdesc: this.dataSelect.type.name, edesc: this.dataSelect.type.edesc, shortName: this.dataSelect.type.code, expectationLevel: this.dataSelect.type.level }),
    })
    this.competencytopicService.delete(body).subscribe((response: any) => {
      if (response.success) {
        this.showSuccessDelete()
        this.getCompetencytopicList()
      }
    })
  }
  currentModal = "";

  constructor(private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private competencytopicService: CompetencytopicService,
    private competencytypeService: CompetencytypeService
  ) { }
  ngOnInit(): void {
    this.getCompetencytopicList()
    this.getCompetencytypeList()
  }
  getCompetencytypeList() {
    this.competencytypeListLoading = true
    this.competencytypeService.getList().subscribe({
      next: response => {
        this.competencytypeList = response.map(x => ({ id: x.competencyTypeId, name: x.tdesc, edesc: x.edesc, code: x.shortName, level: x.expectationLevel, checked: false }))
        this.competencytypeListLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.competencytypeListLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  searchCompetencytypeChange() {
    this.currentPageModal = 1
    this.pageModal = Array.from({ length: Math.ceil(this.competencytypeListFilter().length / 10) }, (_, i) => i + 1);
  }
  competencytypeListFilter() {
    return this.competencytypeList.filter(x => {
      const data = x
      const match = data.id.includes(this.searchModal) || data.name.includes(this.searchModal) || data.code.includes(this.searchModal);
      return match;
    });
  }
  selectCompetencytype(data: DataModel2) {
    this.dataSelect.type = JSON.parse(JSON.stringify(data));
  }
  getCompetencytopicList() {
    this.dataLoading = true
    this.competencytopicService.getList().subscribe({
      next: response => {
        this.mockData = response.map(x => ({
          id: x.competencyTopicId, name: x.tdesc, edesc: x.edesc, code: x.competencyType.shortName, definition: x.competencyDetail,
          type: { id: x.competencyType.competencyTypeId, name: x.competencyType.tdesc, edesc: x.competencyType.edesc, code: x.competencyType.shortName, level: x.expectationLevel },
          checked: false
        }))
        this.dataLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.dataLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.dataListFilter().length / 10) }, (_, i) => i + 1);
  }
  dataListFilter() {
    return this.mockData.filter(x => {
      const data = x
      const match = data.id.includes(this.search) || data.name.includes(this.search) || data.code.includes(this.search);
      return match;
    });
  }
  selectCompetencytopic(data?: DataModel) {
    this.dataSelect = JSON.parse(JSON.stringify(data || { id: "", name: "", edesc: "", code: "", definition: "", type: { id: "", name: "", edesc: "", code: "", level: "" }, checked: false }));
  }

  showSuccess() {
    this.toastr.success('บันทึกข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }

  showSuccessEdit() {
    this.toastr.success('เเก้ไขข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }

  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
}
