import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { MyCompetencytypeModel } from 'src/app/shared/model/competencytype.model';
import { CompetencytypeService } from 'src/app/shared/services/competencytype.service';
export interface DataModel {
  id: string
  name: string
  edesc: string
  code: string
  level: string
  checked: boolean
}
@Component({
  selector: 'app-type-registration',
  templateUrl: './type-registration.component.html',
  styleUrls: ['./type-registration.component.scss']
})
export class TypeRegistration {
  @Input() pathTitle = ['การประเมินสมรรถนะ', 'ทะเบียนกำหนดชื่อ', 'ประเภทสมรรถนะ'];
  @Output() sendPathTitle: EventEmitter<string[]> = new EventEmitter<string[]>();
  activeTab: string = 'tab1'; // กำหนด tab เริ่มต้น
  isChecked: boolean = false;


  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = ""


  // ฟังก์ชันในการเปลี่ยนแท็บ
  changeTab(tab: { id: string, text: string }) {
    this.sendPathTitle.emit(['การประเมินสมรรถนะ', 'ทะเบียนกำหนดชื่อ', tab.text]);
    this.activeTab = tab.id;
  }



  // การจัดการการเปิดปิด modal
  modalOptions: {
    [nameModal: string]: {
      isModalOpen: boolean;
      modalSize: string;
      backdropClose: boolean;
    };
  } = {
      "add": {
        isModalOpen: false,
        modalSize: 'm',
        backdropClose: true,
      },
      "edit": {
        isModalOpen: false,
        modalSize: 'm',
        backdropClose: true,
      }
    };


  toggleCheckbox(): void {
    this.isChecked = !this.isChecked;
    this.mockData.forEach((item) => {
      item.checked = this.isChecked;
    });
    this.checkSelect();
  }

  mockData: DataModel[] = []
  dataLoading = false
  dataSelect: DataModel = { id: "", name: "", edesc: "", code: "", level: "", checked: false }
  mockDataSelect: any = []

  checkSelect() {
    this.mockDataSelect = this.mockData.filter(item => item.checked);
  }

  openModal(name: string, size: string, closeOnBackdrop?: boolean) {
    this.modalOptions[name].modalSize = size;
    this.modalOptions[name].backdropClose = closeOnBackdrop || false;
    this.modalOptions[name].isModalOpen = true;
    this.currentModal = name;  // ตั้งค่าค่าของ currentModal เป็น 'add' หรือ 'edit'
    document.body.style.overflow = 'hidden';
  }

  closeModal(name: string) {
    this.modalOptions[name].isModalOpen = false;
    if (!this.isAnyModalOpen()) {
      document.body.style.overflow = ''; // คืนค่าการ Scroll เฉพาะเมื่อ Modal ทั้งหมดปิดแล้ว
    }
  }

  isAnyModalOpen(): boolean {
    return Object.values(this.modalOptions).some(modal => modal.isModalOpen); // ตรวจสอบว่า modal อื่นยังเปิดอยู่หรือไม่
  }

  // ฟังก์ชันสำหรับการเพิ่ม ลบ หรือแก้ไข ข้อมูล
  addUser() {
    const body = new MyCompetencytypeModel({ competencyTypeId: this.dataSelect.id, tdesc: this.dataSelect.name, edesc: this.dataSelect.edesc, shortName: this.dataSelect.code, expectationLevel: this.dataSelect.level })
    this.competencytypeService.post(body).subscribe((response: any) => {
      if (response.success) {
        this.showSuccess()
        this.getCompetencytypeList()
      }
    })
  }
  deleteUser() {
    const body = new MyCompetencytypeModel({ competencyTypeId: this.dataSelect.id, tdesc: this.dataSelect.name, edesc: this.dataSelect.edesc, shortName: this.dataSelect.code, expectationLevel: this.dataSelect.level })
    this.competencytypeService.delete(body).subscribe((response: any) => {
      if (response.success) {
        this.showSuccessDelete()
        this.getCompetencytypeList()
      }
    })
  }
  currentModal = ""
  constructor(private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private competencytypeService: CompetencytypeService
  ) { }
  ngOnInit(): void {
    this.getCompetencytypeList()
  }
  getCompetencytypeList() {
    this.dataLoading = true
    this.competencytypeService.getList().subscribe({
      next: response => {
        this.mockData = response.map(x => ({ id: x.competencyTypeId, name: x.tdesc, edesc: x.edesc, code: x.shortName, level: x.expectationLevel, checked: false }))
        this.dataLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.dataLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.dataListFilter().length / 10) }, (_, i) => i + 1);
  }
  dataListFilter() {
    return this.mockData.filter(x => {
      const data = x
      const match = data.id.includes(this.search) || data.name.includes(this.search) || data.code.includes(this.search);
      return match;
    });
  }
  selectCompetencytype(data?: DataModel) {
    this.dataSelect = JSON.parse(JSON.stringify(data || { id: "", name: "", edesc: "", code: "", level: "", checked: false }));
  }

  showSuccess() {
    this.toastr.success('บันทึกข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessEdit() {
    this.toastr.success('เเก้ไขข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
}

